|Travis CI Status|

-----------------------------------------------------------------------------------------------------

Python-bioformats is a Python wrapper for Bio-Formats, a standalone
Java library for reading and writing life sciences image file
formats. Bio-Formats is capable of parsing both pixels and metadata
for a large number of formats, as well as writing to several
formats. Python-bioformats uses the python-javabridge to start a Java
virtual machine from Python and interact with it. Python-bioformats
was developed for and is used by the cell image analysis software
CellProfiler (cellprofiler.org).  While we are gratified that others
outside the CellProfiler team find it useful, we maintain python-bioformats
essentially for the CellProfiler project and **cannot guarantee support 
for other users.** Please consider visiting our forum at forum.image.sc 
for additional support help.

PyPI record: https://pypi.python.org/pypi/python-bioformats

Documentation: http://pythonhosted.org/python-bioformats/

GitHub repository: https://github.com/CellProfiler/python-bioformats

Report bugs here: https://github.com/CellProfiler/python-bioformats/issues

python-bioformats is licensed under the GNU General Public License
(GPL).  Many files are licensed under the more permissive BSD license.
See the accompanying files COPYING and LICENSE for details.

Copyright (c) 2009-2021 Broad Institute. All rights reserved.


.. |Travis CI Status| image:: https://travis-ci.org/CellProfiler/python-bioformats.svg?branch=master
   :target: https://travis-ci.org/CellProfiler/python-bioformats
